==> kubernetes-model-2.0.8-sources.jar: io/fabric8/openshift/api/model/ProjectFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;

public class ProjectFluentImpl<A extends ProjectFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ProjectFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ProjectSpecBuilder spec;
    private ProjectStatusBuilder status;

    public ProjectFluentImpl(){
    }
    public ProjectFluentImpl(Project instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion!=null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind!=null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata!=null;
    }

    public ProjectFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ProjectFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ProjectFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ProjectFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ProjectFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 */
@Deprecated public ProjectSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public ProjectSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ProjectSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new ProjectSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec!=null;
    }

    public ProjectFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ProjectFluent.SpecNested<A> withNewSpecLike(ProjectSpec item){
            return new SpecNestedImpl(item);
    }

    public ProjectFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ProjectFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new ProjectSpecBuilder().build());
    }

    public ProjectFluent.SpecNested<A> editOrNewSpecLike(ProjectSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 */
@Deprecated public ProjectStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public ProjectStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(ProjectStatus status){
            _visitables.remove(this.status);
            if (status!=null){ this.status= new ProjectStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status!=null;
    }

    public ProjectFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ProjectFluent.StatusNested<A> withNewStatusLike(ProjectStatus item){
            return new StatusNestedImpl(item);
    }

    public ProjectFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ProjectFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new ProjectStatusBuilder().build());
    }

    public ProjectFluent.StatusNested<A> editOrNewStatusLike(ProjectStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public A withNewStatus(String phase){
            return (A)withStatus(new ProjectStatus(phase));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ProjectFluentImpl that = (ProjectFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ProjectFluent.MetadataNested<N>> implements ProjectFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ProjectFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends ProjectSpecFluentImpl<ProjectFluent.SpecNested<N>> implements ProjectFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ProjectSpecBuilder builder;
    
            SpecNestedImpl(ProjectSpec item){
                    this.builder = new ProjectSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new ProjectSpecBuilder(this);
            }
    
    public N and(){
            return (N) ProjectFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends ProjectStatusFluentImpl<ProjectFluent.StatusNested<N>> implements ProjectFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ProjectStatusBuilder builder;
    
            StatusNestedImpl(ProjectStatus item){
                    this.builder = new ProjectStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new ProjectStatusBuilder(this);
            }
    
    public N and(){
            return (N) ProjectFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> kubernetes-model-4.2.1-sources.jar: io/fabric8/openshift/api/model/ProjectFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import javax.validation.Valid;
import java.lang.Object;

public class ProjectFluentImpl<A extends ProjectFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ProjectFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ProjectSpecBuilder spec;
    private ProjectStatusBuilder status;

    public ProjectFluentImpl(){
    }
    public ProjectFluentImpl(Project instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public ProjectFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ProjectFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ProjectFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ProjectFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ProjectFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ProjectSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public ProjectSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ProjectSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new ProjectSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public ProjectFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ProjectFluent.SpecNested<A> withNewSpecLike(ProjectSpec item){
            return new SpecNestedImpl(item);
    }

    public ProjectFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ProjectFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new ProjectSpecBuilder().build());
    }

    public ProjectFluent.SpecNested<A> editOrNewSpecLike(ProjectSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ProjectStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public ProjectStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(ProjectStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new ProjectStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public A withNewStatus(String phase){
            return (A)withStatus(new ProjectStatus(phase));
    }

    public ProjectFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ProjectFluent.StatusNested<A> withNewStatusLike(ProjectStatus item){
            return new StatusNestedImpl(item);
    }

    public ProjectFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ProjectFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new ProjectStatusBuilder().build());
    }

    public ProjectFluent.StatusNested<A> editOrNewStatusLike(ProjectStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ProjectFluentImpl that = (ProjectFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ProjectFluent.MetadataNested<N>> implements ProjectFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ProjectFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends ProjectSpecFluentImpl<ProjectFluent.SpecNested<N>> implements ProjectFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ProjectSpecBuilder builder;
    
            SpecNestedImpl(ProjectSpec item){
                    this.builder = new ProjectSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new ProjectSpecBuilder(this);
            }
    
    public N and(){
            return (N) ProjectFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends ProjectStatusFluentImpl<ProjectFluent.StatusNested<N>> implements ProjectFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ProjectStatusBuilder builder;
    
            StatusNestedImpl(ProjectStatus item){
                    this.builder = new ProjectStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new ProjectStatusBuilder(this);
            }
    
    public N and(){
            return (N) ProjectFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
